aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal/platforms/STM32/usb_lld.h
diff options
context:
space:
mode:
Diffstat (limited to 'os/hal/platforms/STM32/usb_lld.h')
-rw-r--r--os/hal/platforms/STM32/usb_lld.h18
1 files changed, 2 insertions, 16 deletions
diff --git a/os/hal/platforms/STM32/usb_lld.h b/os/hal/platforms/STM32/usb_lld.h
index 4eebda951..c1b00de06 100644
--- a/os/hal/platforms/STM32/usb_lld.h
+++ b/os/hal/platforms/STM32/usb_lld.h
@@ -46,16 +46,6 @@
*/
#define USB_SET_ADDRESS_MODE USB_LATE_SET_ADDRESS
-/**
- * @brief Enables the packet mode for an IN endpoint.
- */
-#define USB_EP_FLAGS_IN_PACKET_MODE 1
-
-/**
- * @brief Enables the packet mode for an OUT endpoint.
- */
-#define USB_EP_FLAGS_OUT_PACKET_MODE 2
-
/*===========================================================================*/
/* Driver pre-compile time settings. */
/*===========================================================================*/
@@ -109,9 +99,9 @@
*/
typedef struct {
/**
* @brief Type of the endpoint.
*/
- usbeptype_t ep_type;
+ uint32_t ep_mode;
/**
* @brief IN endpoint notification callback.
* @details This field must be set to @p NULL if the IN endpoint is not
@@ -138,10 +128,6 @@ typedef struct {
uint16_t out_maxsize;
/* End of the mandatory fields.*/
/**
- * @bief Endpoint mode flags.
- */
- uint16_t flags;
- /**
* @brief Endpoint IN buffer address as offset in the PMA.
*/
uint16_t inaddr;
@@ -109,9 +99,9 @@
typedef struct {
/**
- * @brief Type of the endpoint.
+ * @brief Type and mode of the endpoint.
*/